scilpy.gradients package
===============================

scilpy.gradients.bvec\_bval\_tools module
------------------------------------------------------

.. automodule:: scilpy.gradients.bvec_bval_tools
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.gradients.gen\_gradient\_sampling module
------------------------------------------------------

.. automodule:: scilpy.gradients.gen_gradient_sampling
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.gradients.optimize\_gradient\_sampling module
-----------------------------------------------------------

.. automodule:: scilpy.gradients.optimize_gradient_sampling
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.gradients.utils module
-------------------------------------------------------

.. automodule:: scilpy.gradients.utils
   :members:
   :undoc-members:
   :show-inheritance:
